@@ -12,6 +12,7 @@ ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
 ZUUL_BRANCH=${ZUUL_BRANCH:-}
 CLI_TEST=${CLI_TEST:-false}
 BOOT_MODE=${BOOT_MODE:-}
+ENABLE_GRUB_NETWORK_BOOT=${ENABLE_GRUB_NETWORK_BOOT:-false}
 ENABLE_TLS=${ENABLE_TLS:-false}
 ENABLE_PROMETHEUS_EXPORTER=${ENABLE_PROMETHEUS_EXPORTER:-false}
 USE_VMEDIA=${USE_VMEDIA:-false}
@@ -31,7 +32,7 @@ USE_VMEDIA=${USE_VMEDIA:-false}
 VM_DOMAIN_TYPE=qemu
 export VM_DISK_CACHE="unsafe"
 TEST_VM_NUM_NODES=1
-USE_CIRROS=true
+DOWNLOAD_CUSTOM_DEPLOY_IMAGE=true
 TESTING_USER=cirros
 TEST_PLAYBOOK="test-bifrost.yaml"
 USE_INSPECTOR=true
@@ -45,6 +46,7 @@ PROVISION_WAIT_TIMEOUT=${PROVISION_WAIT_TIMEOUT:-900}
 NOAUTH_MODE=${NOAUTH_MODE:-false}
 CLOUD_CONFIG=""
 WAIT_FOR_DEPLOY=true
+TEST_VM_NODE_DRIVER=${TEST_VM_NODE_DRIVER:-}
 
 # Get OS information
 source /etc/os-release || source /usr/lib/os-release
@@ -72,6 +74,12 @@ if which setenforce &> /dev/null; then
     sudo setenforce Enforcing
 fi
 
+if [ ${DOWNLOAD_CUSTOM_DEPLOY_IMAGE} = "true" ] && [ ! -f "$HOME/.ssh/id_ecdsa.pub" ]; then
+    # CentOS/RHEL 8 and 9, as well as Fedora, do not work with the RSA key
+    # that the Cirros' SSH server uses. Generate an ECDSA key pair instead.
+    ssh-keygen -t ECDSA -f "$HOME/.ssh/id_ecdsa" -N ""
+fi
+
 # Note(cinerama): activate is not compatible with "set -u";
 # disable it just for this line.
 set +u
@@ -88,8 +96,9 @@ if [ ${USE_DHCP} = "true" ]; then
     INVENTORY_DHCP=true
     INVENTORY_DHCP_STATIC_IP=true
     WRITE_INTERFACES_FILE=false
+    CLOUD_CONFIG+=" -e dhcp_provider=none"
 elif [ ${BUILD_IMAGE} = "true" ]; then
-    USE_CIRROS=false
+    DOWNLOAD_CUSTOM_DEPLOY_IMAGE=false
     TESTING_USER=root
     VM_MEMORY_SIZE="4096"
     ENABLE_INSPECTOR=false
@@ -102,6 +111,8 @@ elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     CLOUD_CONFIG+=" -e cloud_name=bifrost"
 fi
 
+REDEPLOY_NODES=$DOWNLOAD_CUSTOM_DEPLOY_IMAGE
+
 if [[ -n "$BOOT_MODE" ]]; then
     CLOUD_CONFIG+=" -e default_boot_mode=$BOOT_MODE"
     VM_SETUP_EXTRA+=" -e default_boot_mode=$BOOT_MODE"
@@ -110,21 +121,16 @@ fi
 if [ ${USE_VMEDIA} = "true" ]; then
     TEST_VM_NODE_DRIVER=redfish
     CLOUD_CONFIG+=" -e default_boot_interface=redfish-virtual-media"
-    # The default won't work for other hardware types
-    CLOUD_CONFIG+=" -e enabled_hardware_types=redfish"
+elif [ ${ENABLE_GRUB_NETWORK_BOOT} = "true" ]; then
+    CLOUD_CONFIG+=" -e default_boot_interface=pxe"
 fi
 
-CURRENT_CRYPTO_POLICY=
-if [ ${USE_CIRROS} = "true" ] && which update-crypto-policies 2>&1 > /dev/null; then
-    # Crypto policies in newer Fedora prevent SSH into Cirros
-    CURRENT_CRYPTO_POLICY=$(sudo update-crypto-policies --show)
-    sudo update-crypto-policies --set LEGACY
+if [[ -n "$TEST_VM_NODE_DRIVER" ]]; then
+    VM_SETUP_EXTRA+=" --driver $TEST_VM_NODE_DRIVER"
+    CLOUD_CONFIG+=" -e enabled_hardware_types=$TEST_VM_NODE_DRIVER"
 fi
 
 on_exit() {
-    if [ -n "$CURRENT_CRYPTO_POLICY}" ]; then
-        sudo update-crypto-policies --set $CURRENT_CRYPTO_POLICY || true
-    fi
     $SCRIPT_HOME/collect-test-info.sh
 }
 trap on_exit EXIT
@@ -151,7 +157,6 @@ done
     --memory ${VM_MEMORY_SIZE:-1024} \
     --disk ${VM_DISK:-5} \
     --inventory "${BAREMETAL_DATA_FILE}" \
-    --driver ${TEST_VM_NODE_DRIVER:-ipmi} \
     --extra-vars git_url_root="${WORKSPACE:-https://opendev.org}" \
     ${VM_SETUP_EXTRA:-} \
     ${BIFROST_CLI_EXTRA:-}
@@ -183,7 +188,7 @@ ${ANSIBLE} -vvvv \
     -i inventory/bifrost_inventory.py \
     -i inventory/target \
     ${TEST_PLAYBOOK} \
-    -e use_cirros=${USE_CIRROS} \
+    -e download_custom_deploy_image=${DOWNLOAD_CUSTOM_DEPLOY_IMAGE} \
     -e use_tinyipa=true \
     -e testing_user=${TESTING_USER} \
     -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
@@ -191,6 +196,7 @@ ${ANSIBLE} -vvvv \
     -e inventory_dhcp_static_ip=${INVENTORY_DHCP_STATIC_IP} \
     -e enable_inspector=${USE_INSPECTOR} \
     -e inspect_nodes=${INSPECT_NODES} \
+    -e redeploy_nodes=${REDEPLOY_NODES} \
     -e download_ipa=${DOWNLOAD_IPA} \
     -e create_ipa_image=${CREATE_IPA_IMAGE} \
     -e write_interfaces_file=${WRITE_INTERFACES_FILE} \
